==> cv-dialog-sdk-4.14.0.tgz: package/src/js/catavolt/models/types.js <==
export var DialogModeEnum;
(function (DialogModeEnum) {
    DialogModeEnum["COPY"] = "COPY";
    DialogModeEnum["CREATE"] = "CREATE";
    DialogModeEnum["READ"] = "READ";
    DialogModeEnum["UPDATE"] = "UPDATE";
    DialogModeEnum["DESTROYED"] = "DESTROYED";
    DialogModeEnum["DELETE"] = "DELETE";
    DialogModeEnum["LIST"] = "LIST";
})(DialogModeEnum || (DialogModeEnum = {}));
export var QueryDirectionEnum;
(function (QueryDirectionEnum) {
    QueryDirectionEnum["FORWARD"] = "FORWARD";
    QueryDirectionEnum["BACKWARD"] = "BACKWARD";
})(QueryDirectionEnum || (QueryDirectionEnum = {}));
export var ViewModeEnum;
(function (ViewModeEnum) {
    ViewModeEnum["READ"] = "READ";
    ViewModeEnum["WRITE"] = "WRITE";
})(ViewModeEnum || (ViewModeEnum = {}));
export var TypeNames;
(function (TypeNames) {
    TypeNames["ActionParametersTypeName"] = "hxgn.api.dialog.ActionParameters";
    TypeNames["AppWindowTypeName"] = "hxgn.api.dialog.AppWindow";
    TypeNames["BarcodeScan"] = "hxgn.api.dialog.BarcodeScan";
    TypeNames["CalendarTypeName"] = "hxgn.api.dialog.Calendar";
    TypeNames["CodeRefTypeName"] = "hxgn.api.dialog.CodeRef";
    TypeNames["ContentRedirectionTypeName"] = "hxgn.api.dialog.ContentRedirection";
    TypeNames["DetailsTypeName"] = "hxgn.api.dialog.Details";
    TypeNames["DialogTypeName"] = "hxgn.api.dialog.Dialog";
    TypeNames["DialogMessageTypeName"] = "hxgn.api.dialog.DialogMessage";
    TypeNames["DialogRedirectionTypeName"] = "hxgn.api.dialog.DialogRedirection";
    TypeNames["EditorDialogTypeName"] = "hxgn.api.dialog.EditorDialog";
    TypeNames["FormTypeName"] = "hxgn.api.dialog.Form";
    TypeNames["GpsReadingTypeName"] = "hxgn.api.dialog.GpsReading";
    TypeNames["GpsReadingPropertyTypeName"] = "hxgn.api.dialog.GpsReadingProperty";
    TypeNames["GraphTypeName"] = "hxgn.api.dialog.Graph";
    TypeNames["LargePropertyTypeName"] = "hxgn.api.dialog.LargeProperty";
    TypeNames["ListTypeName"] = "hxgn.api.dialog.List";
    TypeNames["LoginTypeName"] = "hxgn.api.dialog.Login";
    TypeNames["MapTypeName"] = "hxgn.api.dialog.Map";
    TypeNames["MapLocationTypeName"] = "hxgn.api.dialog.MapLocation";
    TypeNames["MapLocationPropertyTypeName"] = "hxgn.api.dialog.MapLocationProperty";
    TypeNames["NullRedirectionTypeName"] = "hxgn.api.dialog.NullRedirection";
    TypeNames["ObjectRefTypeName"] = "hxgn.api.dialog.ObjectRef";
    TypeNames["PropertyTypeName"] = "hxgn.api.dialog.Property";
    TypeNames["QueryDialogTypeName"] = "hxgn.api.dialog.QueryDialog";
    TypeNames["QueryParametersTypeName"] = "hxgn.api.dialog.QueryParameters";
    TypeNames["ReadLargePropertyParameters"] = "hxgn.api.dialog.ReadLargePropertyParameters";
    TypeNames["RecordTypeName"] = "hxgn.api.dialog.Record";
    TypeNames["ReferringDialogTypeName"] = "hxgn.api.dialog.ReferringDialog";
    TypeNames["ReferringWorkbenchTypeName"] = "hxgn.api.dialog.ReferringWorkbench";
    TypeNames["SessionTypeName"] = "hxgn.api.dialog.Session";
    TypeNames["StreamTypeName"] = "hxgn.api.dialog.Stream";
    TypeNames["WebRedirectionTypeName"] = "hxgn.api.dialog.WebRedirection";
    TypeNames["WorkbenchTypeName"] = "hxgn.api.dialog.Workbench";
    TypeNames["WorkbenchRedirectionTypeName"] = "hxgn.api.dialog.WorkbenchRedirection";
    TypeNames["WriteLargePropertyParameters"] = "hxgn.api.dialog.WriteLargePropertyParameters";
})(TypeNames || (TypeNames = {}));

==> cv-dialog-sdk-4.26.9.tgz: package/src/js/catavolt/models/types.js <==
export var DialogModeEnum;
(function (DialogModeEnum) {
    DialogModeEnum["COPY"] = "COPY";
    DialogModeEnum["CREATE"] = "CREATE";
    DialogModeEnum["READ"] = "READ";
    DialogModeEnum["UPDATE"] = "UPDATE";
    DialogModeEnum["DESTROYED"] = "DESTROYED";
    DialogModeEnum["DELETE"] = "DELETE";
    DialogModeEnum["LIST"] = "LIST";
})(DialogModeEnum || (DialogModeEnum = {}));
export var QueryDirectionEnum;
(function (QueryDirectionEnum) {
    QueryDirectionEnum["FORWARD"] = "FORWARD";
    QueryDirectionEnum["BACKWARD"] = "BACKWARD";
})(QueryDirectionEnum || (QueryDirectionEnum = {}));
export var ViewModeEnum;
(function (ViewModeEnum) {
    ViewModeEnum["READ"] = "READ";
    ViewModeEnum["WRITE"] = "WRITE";
})(ViewModeEnum || (ViewModeEnum = {}));
export var TypeNames;
(function (TypeNames) {
    TypeNames["ActionParametersTypeName"] = "hxgn.api.dialog.ActionParameters";
    TypeNames["AppWindowTypeName"] = "hxgn.api.dialog.AppWindow";
    TypeNames["BarcodeScanTypeName"] = "hxgn.api.dialog.BarcodeScan";
    TypeNames["CalendarTypeName"] = "hxgn.api.dialog.Calendar";
    TypeNames["CodeRefTypeName"] = "hxgn.api.dialog.CodeRef";
    TypeNames["ContentRedirectionTypeName"] = "hxgn.api.dialog.ContentRedirection";
    TypeNames["DetailsTypeName"] = "hxgn.api.dialog.Details";
    TypeNames["DialogTypeName"] = "hxgn.api.dialog.Dialog";
    TypeNames["DialogMessageTypeName"] = "hxgn.api.dialog.DialogMessage";
    TypeNames["DialogRedirectionTypeName"] = "hxgn.api.dialog.DialogRedirection";
    TypeNames["EditorDialogTypeName"] = "hxgn.api.dialog.EditorDialog";
    TypeNames["FormTypeName"] = "hxgn.api.dialog.Form";
    TypeNames["GpsReadingTypeName"] = "hxgn.api.dialog.GpsReading";
    TypeNames["GpsReadingPropertyTypeName"] = "hxgn.api.dialog.GpsReadingProperty";
    TypeNames["GraphTypeName"] = "hxgn.api.dialog.Graph";
    TypeNames["LargePropertyTypeName"] = "hxgn.api.dialog.LargeProperty";
    TypeNames["ListTypeName"] = "hxgn.api.dialog.List";
    TypeNames["LoginTypeName"] = "hxgn.api.dialog.Login";
    TypeNames["MapTypeName"] = "hxgn.api.dialog.Map";
    TypeNames["MapLocationTypeName"] = "hxgn.api.dialog.MapLocation";
    TypeNames["MapLocationPropertyTypeName"] = "hxgn.api.dialog.MapLocationProperty";
    TypeNames["NullRedirectionTypeName"] = "hxgn.api.dialog.NullRedirection";
    TypeNames["ObjectRefTypeName"] = "hxgn.api.dialog.ObjectRef";
    TypeNames["PropertyTypeName"] = "hxgn.api.dialog.Property";
    TypeNames["QueryDialogTypeName"] = "hxgn.api.dialog.QueryDialog";
    TypeNames["QueryParametersTypeName"] = "hxgn.api.dialog.QueryParameters";
    TypeNames["ReadLargePropertyParameters"] = "hxgn.api.dialog.ReadLargePropertyParameters";
    TypeNames["RecordTypeName"] = "hxgn.api.dialog.Record";
    TypeNames["ReferringDialogTypeName"] = "hxgn.api.dialog.ReferringDialog";
    TypeNames["ReferringWorkbenchTypeName"] = "hxgn.api.dialog.ReferringWorkbench";
    TypeNames["SessionTypeName"] = "hxgn.api.dialog.Session";
    TypeNames["StreamTypeName"] = "hxgn.api.dialog.Stream";
    TypeNames["WebRedirectionTypeName"] = "hxgn.api.dialog.WebRedirection";
    TypeNames["WorkbenchTypeName"] = "hxgn.api.dialog.Workbench";
    TypeNames["WorkbenchRedirectionTypeName"] = "hxgn.api.dialog.WorkbenchRedirection";
    TypeNames["WriteLargePropertyParameters"] = "hxgn.api.dialog.WriteLargePropertyParameters";
})(TypeNames || (TypeNames = {}));
